@@ -7,13 +7,13 @@ use strict;
 use warnings;
 #use Carp;
 
-our $VERSION = '0.01_01';
+our $VERSION = '0.01_02';
+our $ISA     = qw/Qt::Core::QObject/;
 
 
 # FIXME: operator overload
 
 
-
 1;
 
 =head1 NAME
@@ -24,11 +24,18 @@ Qt::Network::QNetworkCookieJar
 
 =over
 
-=item    QNetworkCookieJar(QObject * parent = 0)
+=item   QNetworkCookieJar(QObject * parent)
 
-=item    QNetworkCookieJar(QObject * parent)
+=item   QNetworkCookieJar(QObject * parent = 0)
 
-=item    ~QNetworkCookieJar()
+=item   ~QNetworkCookieJar()
+
+
+=back
+
+=head1 ENUM VALUES
+
+=over
 
 
 =back
